California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 78 - PRESCRIPTION DRUGS. DISCOUNTS. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1274444 | PHARMACEUTICAL RESEARCH AND MANUFACTURERS OF AMERICA CALIFORNIA INITIATIVE FUND | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1275570 | CALIFORNIANS FOR AFFORDABLE PRESCRIPTIONS - YES ON PROPOSITION 78 SPONSORED BY PHARMACEUTICAL REASEARCH AND MANUFACTURERS OF AMERICA | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1280140 | CALIFORNIANS AGAINST ARNOLD'S SPECIAL INTEREST ELECTION - NO ON 73, 74, 75, 76, 77 AND 78 AND YES ON 79 AND 80, SPONSORED BY WORKING ASSETS AND BALLOT INITIATIVE STRATEGY CENTER | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1278872 | NO SPECIAL ELECTION - 41ST AD FIGHTING PROPOSITIONS 73, 74, 75, 76 AND 78 | OPPOSE